#
# spec file for package ghc-hslua-aeson
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-aeson
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.3.1.1
Release:        1.2
Summary:        Allow aeson data types to be used with Lua
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-hslua-core-devel
BuildRequires:  ghc-hslua-core-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-scientific-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-quickcheck-instances-devel
BuildRequires:  ghc-quickcheck-instances-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This package provides instances to push and receive any datatype encodable as
JSON to and from the Lua stack.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Jul  9 2024 Peter Simons <psimons@suse.com>
- Update hslua-aeson to version 2.3.1.1.
  [#]# hslua-aeson-2.3.1.1
  Released 2024-07-09.
  - Relaxed upper bound for hashable, allowing hashable-1.5.
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-aeson to version 2.3.1.
  [#]# hslua-aeson-2.3.1
  Released 2024-01-18.
  - Relaxed upper bound for aeson. This required changes to the
    testsuite: The arbitrary JSON values produced by current aeson
    versions include numbers that cannot be converted to Lua
    numbers without loss of precision. Those are first converted
    to representable numbers before round-tripping is tested.
  - Relaxed upper bound for text, containers, and bytestring,
    allowing text-2.1, containers-0.7, and bytestring-0.12.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-aeson to version 2.3.0.1.
  [#]# hslua-aeson-2.3.0.1
  Released 2023-03-13.
  - Relax upper bound for hslua-marshalling, allow version 2.3.
  [#]# hslua-aeson-2.3.0
  Released 2023-02-21.
  - The `peekValue` peeker now checks for a `__toaeson` metafield
    or `__tojson` metamethod and uses them to compute the `Value`
    of an object:
    The `__toaeson` metafield, if set, must be a function pushed
    via `pushToAeson`. That function is called on a given object,
    and the returned *Value* becomes the result of calling
    `peekValue`.
    Likewise, the `__tojson` metamethod must be a function that
    returns a valid JSON string. The result in that case is the
    decoded string.
    If both, `__toaeson` and `__tojson` are set, then `__toaeson`
    takes precedent.
  - The test suite now has *tasty-hunit* as an additional
    dependency.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Thu Jun 23 2022 Peter Simons <psimons@suse.com>
- Update hslua-aeson to version 2.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-aeson-2.2.1/src/CHANGELOG.md
* Fri Feb  4 2022 psimons@suse.com
- Add hslua-aeson at version 2.1.0.
